@@ -44,8 +44,8 @@ static sigset_t     pth_sigblock;   /* mask of signals we block in scheduler */
 static sigset_t     pth_sigcatch;   /* mask of signals we have to catch      */
 static sigset_t     pth_sigraised;  /* mask of raised signals                */
 
-static pth_time_t   pth_loadticknext;
-static pth_time_t   pth_loadtickgap = PTH_TIME(1,0);
+static pth_itime_t   pth_loadticknext;
+static pth_itime_t   pth_loadtickgap = PTH_TIME(1,0);
 
 /* initialize the scheduler ingredients */
 intern int pth_scheduler_init(void)
@@ -140,7 +140,7 @@ intern void pth_scheduler_kill(void)
  */
 #define pth_scheduler_load(now) \
     if (pth_time_cmp((now), &pth_loadticknext) >= 0) { \
-        pth_time_t ttmp; \
+        pth_itime_t ttmp; \
         int numready; \
         numready = pth_pqueue_elements(&pth_RQ); \
         pth_time_set(&ttmp, (now)); \
@@ -156,8 +156,8 @@ intern void pth_scheduler_kill(void)
 intern void *pth_scheduler(void *dummy)
 {
     sigset_t sigs;
-    pth_time_t running;
-    pth_time_t snapshot;
+    pth_itime_t running;
+    pth_itime_t snapshot;
     struct sigaction sa;
     sigset_t ss;
     int sig;
@@ -380,11 +380,12 @@ intern void *pth_scheduler(void *dummy)
  * Look whether some events already occurred (or failed) and move
  * corresponding threads from waiting queue back to ready queue.
  */
-intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
+intern void pth_sched_eventmanager(pth_itime_t *now, int dopoll)
 {
     pth_t nexttimer_thread;
     pth_event_t nexttimer_ev;
-    pth_time_t nexttimer_value;
+    pth_itime_t nexttimer_value;
+    pth_itime_t tmp;
     pth_event_t evh;
     pth_event_t ev;
     pth_t t;
@@ -564,7 +565,7 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
                     if (ev->ev_args.FUNC.func(ev->ev_args.FUNC.arg))
                         this_occurred = TRUE;
                     else {
-                        pth_time_t tv;
+                        pth_itime_t tv;
                         pth_time_set(&tv, now);
                         pth_time_add(&tv, &(ev->ev_args.FUNC.tv));
                         if ((nexttimer_thread == NULL && nexttimer_ev == NULL) ||
@@ -592,14 +593,16 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
     if (dopoll) {
         /* do a polling with immediate timeout,
            i.e. check the fd sets only without blocking */
-        pth_time_set(&delay, PTH_TIME_ZERO);
+        pth_zero_time(&delay);
         pdelay = &delay;
     }
     else if (nexttimer_ev != NULL) {
         /* do a polling with a timeout set to the next timer,
            i.e. wait for the fd sets or the next timer */
-        pth_time_set(&delay, &nexttimer_value);
-        pth_time_sub(&delay, now);
+        pth_time_set(&tmp, &nexttimer_value);
+        pth_time_sub(&tmp, now);
+	delay.tv_sec = tmp.t_sec;
+	delay.tv_usec = tmp.t_usec;
         pdelay = &delay;
     }
     else {
@@ -710,7 +713,7 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
                                 FD_SET(ev->ev_args.FD.fd, &wfds);
                             if (ev->ev_goal & PTH_UNTIL_FD_EXCEPTION)
                                 FD_SET(ev->ev_args.FD.fd, &efds);
-                            pth_time_set(&delay, PTH_TIME_ZERO);
+                            pth_zero_time(&delay);
                             while ((rc2 = pth_sc(select)(ev->ev_args.FD.fd+1, &rfds, &wfds, &efds, &delay)) < 0
                                    && errno == EINTR) ;
                             if (rc2 > 0) {
@@ -766,7 +769,7 @@ intern void pth_sched_eventmanager(pth_time_t *now, int dopoll)
                                 memcpy(&tefds, ev->ev_args.SELECT.efds, sizeof(efds));
                                 pefds = &tefds;
                             }
-                            pth_time_set(&delay, PTH_TIME_ZERO);
+                            pth_zero_time(&delay);
                             while ((rc2 = pth_sc(select)(ev->ev_args.SELECT.nfd+1, prfds, pwfds, pefds, &delay)) < 0
                                    && errno == EINTR) ;
                             if (rc2 < 0) {
